@@ -64,7 +64,7 @@ class SignaldAPI(SignaldGeneratedAPI):
             linking_successful.cancel()
             raise
         else:
-            uri = response.get("data", dict()).get("uri")
+            uri = response.get("uri")
             return uri, linking_successful
 
     async def verify(self, username: str, code: str):
